@@ -416,20 +416,38 @@ class Query:
                     formatted_value = None
 
                 if isinstance(where_condition.operator, str):
-                    operator = where_condition.operator
+                    if where_condition.negate is None:
+                        operator = where_condition.operator
+                    else:
+                        operator = "NOT " + where_condition.operator
                 elif isinstance(where_condition.operator, SQLOperator) or isinstance(where_condition.operator,
                                                                                      TimeOperator):
                     operator = where_condition.operator.name
                     if operator == "GOE":
-                        operator = ">="
+                        if where_condition.negate is None:
+                            operator = ">="
+                        else:
+                            operator = "<"
                     elif operator == "LOE":
-                        operator = "<="
+                        if where_condition.negate is None:
+                            operator = "<="
+                        else:
+                            operator = ">"
                     elif operator == "EQ":
-                        operator = "=="
+                        if where_condition.negate is None:
+                            operator = "=="
+                        else:
+                            operator = "!="
                     elif operator == "GT":
-                        operator = ">"
+                        if where_condition.negate is None:
+                            operator = ">"
+                        else:
+                            operator = "<="
                     elif operator == "LT":
-                        operator = "<"
+                        if where_condition.negate is None:
+                            operator = "<"
+                        else:
+                            operator = ">="
                 else:
                     operator = None
 
